@@ -17,8 +17,9 @@ is defined as::
         super(Function,self).__init__(expression, pl, pr)
             
     def info(self):
-        return '%s%s' % (self.func,super(Function,self).info())
+        return '{0}{1}'.format(self.func,super(Function,self).info())
     
     def _unwind(self, values, backend, **kwargs):
         args,kwargs = super(Function,self)._unwind(values, backend, **kwargs)
         return self.func(args,**kwargs)
+
